#ifndef NT2_INCLUDE_FUNCTIONS_QR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_QR_HPP_INCLUDED

#include <nt2/linalg/include/functions/qr.hpp>

#endif
